@@ -1,7 +1,7 @@
 package usw;
 use 5.012005;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 use Encode qw(is_utf8 encode_utf8 decode_utf8);
 use utf8();
@@ -14,7 +14,7 @@ sub import {
     strict->import;
     warnings->import( 'all', FATAL => 'recursion' );
 
-    binmode \*STDIN,  ":encoding(UTF-8)";
+    #binmode \*STDIN,  ":encoding(UTF-8)";
     binmode \*STDOUT, ":encoding(UTF-8)";
     binmode \*STDERR, ":encoding(UTF-8)";
     return unless @_;
@@ -50,10 +50,11 @@ usw - use utf8; use strict; use warnings; in one line.
  use utf8;
  use strict;
  use warnings;
- binmode STDIN,  ':encoding(UTF-8)';
  binmode STDOUT, ':encoding(UTF-8)';
  binmode STDERR, ':encoding(UTF-8)';
 
+=cut #binmode STDIN,  ':encoding(UTF-8)';
+
 =head1 DESCRIPTION
 
 usw is a shortcut pragma mostly for one-liners.
